/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat Inc.  You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license
   agreement you entered into with NetCat Inc.

   Copyright (c) 2003 - 2004 by NetCat Inc., www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/
import java.awt.*;

import li.netcat.chart.*;
import li.netcat.chart.data.*;
import li.netcat.chart.util.*;
import li.netcat.chart.util.tag.*;

public class CollectionExample {
  
  public static void main(String[] args) {
    FrameHelper.open(createCharts(), -1, 3);
  }
  
  public static Chart[] createCharts() {
    ChartModel model = new StudentsChartModel();
    //ChartModel model = new TemperatureChartModel();
    return new Chart[] {
        new BarChart(model, ChartConstants.STACK_TYPE_NOT_STACKED, ChartConstants.HORIZONTAL),
        new BarChart(model, ChartConstants.STACK_TYPE_STACKED, ChartConstants.HORIZONTAL),
        new BarChart(model, ChartConstants.STACK_TYPE_STACKED_PERCENT, ChartConstants.HORIZONTAL),
        new BarChart(model, ChartConstants.STACK_TYPE_NOT_STACKED, ChartConstants.VERTICAL),
        new BarChart(model, ChartConstants.STACK_TYPE_STACKED, ChartConstants.VERTICAL),
        new BarChart(model, ChartConstants.STACK_TYPE_STACKED_PERCENT, ChartConstants.VERTICAL),
        new AreaChart(model, ChartConstants.STACK_TYPE_NOT_STACKED, ChartConstants.HORIZONTAL),
        new AreaChart(model, ChartConstants.STACK_TYPE_STACKED, ChartConstants.HORIZONTAL),
        new AreaChart(model, ChartConstants.STACK_TYPE_STACKED_PERCENT, ChartConstants.HORIZONTAL),
        new AreaChart(model, ChartConstants.STACK_TYPE_NOT_STACKED, ChartConstants.VERTICAL),
        new PieChart(model),
        new RingChart(model),
        new LineChart(model, ChartConstants.STACK_TYPE_NOT_STACKED, ChartConstants.HORIZONTAL, true, false, false),  
        new LineChart(model, ChartConstants.STACK_TYPE_STACKED, ChartConstants.VERTICAL, false, true, true),
        new RadarChart(model, ChartConstants.STACK_TYPE_NOT_STACKED),
        new RadarChart(model, ChartConstants.STACK_TYPE_STACKED),
        new RadarLineChart(model, ChartConstants.STACK_TYPE_NOT_STACKED, true, true),
        new RadarLineChart(model, ChartConstants.STACK_TYPE_STACKED, true, true),
    };
  }
  
  public static class BarChart extends CartesianChart {
    public BarChart(ChartModel model, int type, int orientation) {
      super(new BarPart(model, type, orientation));
    }
  }
  
  public static class AreaChart extends CartesianChart {
    public AreaChart(ChartModel model, int type, int orientation) {
      super(new AreaPart(model, type, orientation)); 
    }
  }
  
  public static class LineChart extends CartesianChart {
    public LineChart(ChartModel model, int type, int orientation, boolean paintLines, boolean paintSymbols, boolean isCentered) {
      super(new LinePart(model, type, orientation, paintLines, paintSymbols));
      ((RowScaleModel)getGraphPart().getDiscreetScaleModel()).setCentered(isCentered);
    }
  }
  
  public static class RadarChart extends PolarChart {
    public RadarChart(ChartModel model, int type) {
      super(new RadarPart(model, type));
    }
  }
  
  public static class RadarLineChart extends PolarChart {
    public RadarLineChart(ChartModel model, int type, boolean paintLines, boolean paintSymbols) {
      super(new RadarLinePart(model, type, paintLines, paintSymbols));
    }
  }

  public static class PieChart extends Chart {
    public PieChart(ChartModel model) {
      RingPart ringPart = new RingPart(new SumRowsChartModel(model), ChartConstants.STACK_TYPE_STACKED_PERCENT);
      ringPart.setSize(48, 0);
      ringPart.setRadialMove(0, 1, 10.0f);
      PanelPart panel = new PanelPart();
      panel.addPart(ringPart);
      panel.addPart(new PolarInscribePart(ringPart));
      setContent(panel);
    }
  }
  
  public static class RingChart extends Chart {
    public RingChart(ChartModel model) {
      RingPart ringPart = new RingPart(model, ChartConstants.STACK_TYPE_STACKED_PERCENT);
      ringPart.setSize(35, 20);
      ringPart.setRadialMove(3, 1, 10.0f);
      CartesianScalePart cartesianScalePart = new CartesianScalePart(ringPart, ChartConstants.LEFT);
      cartesianScalePart.setAdditionalLineLength(ringPart.getRadius()+5);
      cartesianScalePart.setTagManager(new DefaultTagManager(DefaultTagManager.STYLE_UNDERLINE, DefaultTagManager.METHOD_MOVE));
      cartesianScalePart.setPen(Pen.getDefaultCapButt());
      PanelPart panel = new PanelPart();
      panel.addPart(ringPart);
      panel.addPart(cartesianScalePart);
      setContent(panel);
    }
  }
  
  public static class CartesianChart extends Chart {
    private CartesianGraphPart _graphPart;
    
    public CartesianChart(CartesianGraphPart cartesianGraphPart) {
      _graphPart = cartesianGraphPart;
      cartesianGraphPart.setSize(140, 100);
      CartesianGridPart cartesianGridPart = new CartesianGridPart(cartesianGraphPart);
      if (cartesianGraphPart.getOrientation() == CartesianGraphPart.VERTICAL) {
        cartesianGridPart.flipFlags();
      }
      PanelPart panel = new PanelPart();
      panel.addPart(cartesianGridPart);
      panel.addPart(cartesianGraphPart);
      panel.addPart(new CartesianScalePart(cartesianGraphPart, CartesianScalePart.LEFT));
      panel.addPart(new CartesianScalePart(cartesianGraphPart, CartesianScalePart.BOTTOM));
      setContent(panel);
    }
    
    public CartesianGraphPart getGraphPart() {
      return _graphPart;
    }
  }
  
  public static class PolarChart extends Chart {
    public PolarChart(PolarGraphPart polarGraphPart) {
      polarGraphPart.setSize(48, 0);
      PanelPart panel = new PanelPart();
      panel.addPart(new PolarGridPart(polarGraphPart));
      panel.addPart(polarGraphPart);
      panel.addPart(new PolarScalePart(polarGraphPart));
      setContent(panel);
    }
  }
  
  public static class StudentsChartModel extends ExampleChartModel {
  
    //// constructors
    
    public StudentsChartModel() {
      super(new String[] {"Deutsch", "Englisch", "Chemie", "Physik"}, 
            new String[] {"Alexandra", "Debora", "Lukas"},
            new int[] {77, 90, 60, 85,
                       65, 55, 15, 18, 
                       25, 37, 82, 52,
            });
    }
  }

  public static class TemperatureChartModel extends ExampleChartModel {
  
    //// constructors
    
    public TemperatureChartModel() {
      super(new String[] {"Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag", "Samstag", "Sonntag"}, 
            new String[] {"Luft", "Wasser"},
            new double[] {22.4, 21.2, 16.3, 19.8, (0.0D / 0.0D), 23.1, 22.6,
            18.3, 18.6, 18.9, 18.2, 18.4, 18.8, 19.0,
            });
    }

  }
}
