/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat Inc.  You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license
   agreement you entered into with NetCat Inc.

   Copyright (c) 2003 - 2004 by NetCat Inc., www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/

import java.awt.event.*;
import java.awt.*;
import java.awt.geom.*;
import java.util.*;
import java.awt.image.*;
import java.io.*;


import li.netcat.chart.*;
import li.netcat.chart.util.*;
import li.netcat.chart.util.elem.*;

/**
 * This example shows how to export a chart as an image to a file.
 * 
 * Note that this example needs java 1.4 or later
 */
public class ElementIteratorExample {
  
  public static void main(String[] args)	{
    Chart myChart = new BarChart(new MyChartModel());
    // size depends on graphics, create a buffered image as probe
    BufferedImage probe = new BufferedImage(1, 1, BufferedImage.TYPE_INT_ARGB);
    Graphics2D g2 = probe.createGraphics();
    Layout layout = myChart.getContent().getLayout(g2);
    g2.dispose();
    if (layout instanceof IteratableLayout) {
      // downcast to IteratableLayout
      IteratableLayout itLayout = (IteratableLayout)layout; 
      Rectangle2D.Float bounds = new Rectangle2D.Float();
      AffineTransform tr = new AffineTransform();
      float[] coords = new float[6];
      // iterate over all elements
      for (ElementIterator it = itLayout.getElements(); !it.isDone(); it.next()) {
        Element currentElement = it.currentElement();
        LogicalPoint lp = currentElement.getLogicalPoint();
        if (lp != null) {
          // current element represents some data of the model!
          float tx = it.currentTranslateX();
          float ty = it.currentTranslateY();
          currentElement.getBounds(bounds);
          bounds.x += tx; // move bounds to translation
          bounds.y += ty;
          System.out.print("Row "+lp.getRowIndex()+ ", column "+lp.getColumnIndex()+" covers bounds ");
          System.out.println("["+bounds.x+", "+bounds.y+", "+bounds.width+", "+bounds.height+"] ");
          // get more details
          if (currentElement instanceof AreaElement) {
            Shape shape = ((AreaElement)currentElement).getArea();
            // iterate over the shape
            tr.setToTranslation(tx, ty);
            // get a flat pathiterator that only terurns lines
            System.out.println("  Details:");
            for (PathIterator pIt = shape.getPathIterator(tr, 2.0); !pIt.isDone(); pIt.next()) {
              int segment = pIt.currentSegment(coords);
              if (segment == PathIterator.SEG_MOVETO) {
                System.out.println("    MoveTo ["+coords[0]+", "+coords[1]+"], ");
              }
              else if (segment == PathIterator.SEG_LINETO) {
                System.out.println("    LineTo ["+coords[0]+", "+coords[1]+"], ");
              }
              else if (segment == PathIterator.SEG_CLOSE) {
                System.out.println("    Close.");
              }
            }
          }
        }
      }
    }
  }
  
  
  private static class BarChart extends Chart {
    
    public BarChart(ChartModel chartModel) {
      BarPart barPart = new BarPart(chartModel);
      CartesianGridPart grid = new CartesianGridPart(barPart);
      CartesianScalePart scaleX = new CartesianScalePart(barPart, ChartConstants.BOTTOM);
      CartesianScalePart scaleY = new CartesianScalePart(barPart, ChartConstants.LEFT);
      PanelPart panel = new PanelPart();
      panel.addPart(grid);
      panel.addPart(barPart);
      panel.addPart(scaleX);
      panel.addPart(scaleY);
      setContent(panel);
    }
  }
  
  
  private static class MyChartModel extends AbstractChartModel {
    
    //// interface ChartModel
    
    public int getRowCount() {
      return 2;
    }
    
    public int getColumnCount() {
      return 2;
    }
    
    public Object getValueAt(int rowIndex, int columnIndex) {
      return new Integer((1+rowIndex) * (1+columnIndex)); 
    }
    
  }
    
}
