/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat Inc.  You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license 
   agreement you entered into with NetCat Inc.

   Copyright (c) 2003 - 2004 by NetCat Inc., www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/

import li.netcat.chart.*;


public class ExampleChartModel extends AbstractChartModel {
  private String[]  _rowTexts;
  private String[]  _columnTexts;
  private Object[]  _data;
  
  //// constructors
  
  public ExampleChartModel(String[] rowTexts, String[] columnTexts, int[] data) {
    this(rowTexts, columnTexts, convert(data));
  }
  
  public ExampleChartModel(String[] rowTexts, String[] columnTexts, double[] data) {
    this(rowTexts, columnTexts, convert(data));
  }
    
  public ExampleChartModel(String[] rowTexts, String[] columnTexts, Object[] data) {
    if (data.length != rowTexts.length * columnTexts.length) {
      throw new IllegalArgumentException("data.length must be == rowTexts.length * columnTexts.length"); 
    }
    _rowTexts = rowTexts;
    _columnTexts = columnTexts;
    _data = data;
  }
  
  //// interface ChartModel
  
  public int getRowCount() {
    return _rowTexts.length;
  }
  
  public int getColumnCount() {
    return _columnTexts.length;
  }
  
  public Object getValueAt(int rowIndex, int columnIndex) {
    return _data[ columnIndex * _rowTexts.length + rowIndex];
  }
  
  public String getTextForRow(int rowIndex) {
    return _rowTexts[rowIndex];
  }

  public String getTextForColumn(int columnIndex) {
    return _columnTexts[columnIndex];
  }
  
  //// private helpers
  
  private static Object[] convert(int[] values) {
    Object[] result = new Object[values.length];
    for (int i=0; i<values.length; i++) {
      result[i] = new Integer(values[i]);
    }
    return result;
  }
  
  private static Object[] convert(double[] values) {
    Object[] result = new Object[values.length];
    for (int i=0; i<values.length; i++) {
      if (!Double.isNaN(values[i])) {
        result[i] = new Double(values[i]);
      }
    }
    return result;
  }

}
