/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat Inc.  You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license
   agreement you entered into with NetCat Inc.

   Copyright (c) 2004 by NetCat AG, www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/
import java.awt.*;

import li.netcat.chart.*;
import li.netcat.chart.data.*;
import li.netcat.chart.util.*;
import li.netcat.chart.util.tag.*;

public class GridIntervalExample {
  
  public static void main(String[] args) {
    ChartModel model = new ManyRowsModel();
    FrameHelper.open(new Chart[]{new LineChart(model), new RadarLineChart(model)}, 1, -1);
  }

  public static class LineChart extends Chart {
        
    public LineChart(ChartModel chartModel) {
      LinePart linePart = new LinePart(chartModel);
      linePart.setPaintSymbols(false); // don't paint the symbols
      linePart.setSize(200f, 150f); // set the size of the part
      ((DefaultScaleModel)linePart.getNumericScaleModel()).setReverted(true); // revert the numeric scale
      CartesianGridPart grid = new CartesianGridPart(linePart); // construct a grid
      grid.setPaintVerticalLines(true); // grid should paint vertical lines
      grid.setPaintMarksFlags(false, false, false, false); // don't paint marks
      grid.setGridIntervalX(20); // paint lines only every 10 scale marks 
      CartesianScalePart scalePartX = new CartesianScalePart(linePart, CartesianScalePart.BOTTOM);
      scalePartX.setMarkInterval(20);
      CartesianScalePart scalePartY = new CartesianScalePart(linePart, CartesianScalePart.LEFT);
      PanelPart panel = new PanelPart();
      panel.addPart(grid);
      panel.addPart(linePart);
      panel.addPart(scalePartX);
      panel.addPart(scalePartY);
      setContent(panel);
    }
  }
  
  
  public static class RadarLineChart extends Chart {
        
    public RadarLineChart(ChartModel chartModel) {
      RadarLinePart radarLinePart = new RadarLinePart(chartModel);
      radarLinePart.setSize(80f, 20f);
      radarLinePart.setPaintSymbols(false);
      // first and last value should fall together.
      // This is a property of the scale model
      ((RowScaleModel)radarLinePart.getDiscreetScaleModel()).setCentered(false);
      // revert the numeric scale
      ((DefaultScaleModel)radarLinePart.getNumericScaleModel()).setReverted(true);
      PolarGridPart grid = new PolarGridPart(radarLinePart);
      grid.setSpokeInterval(5);
      // prepare a polar scale
      PolarScalePart polarScalePart = new PolarScalePart(radarLinePart);
      polarScalePart.setMarkInterval(10);
      // prepare a cartesian scale
      CartesianScalePart cartesianScalePart = new CartesianScalePart(radarLinePart, CartesianScalePart.LEFT);
      cartesianScalePart.setMarkInterval(2);
      // add everyting to a panel
      PanelPart panel = new PanelPart();
      panel.addPart(grid);
      panel.addPart(radarLinePart);
      panel.addPart(cartesianScalePart);
      panel.addPart(polarScalePart);
      setContent(panel);
    }
  }
  
  public static class ManyRowsModel extends AbstractChartModel {
  
    //// overridden methods
    
    public int getRowCount() {
      return 101;
    }
  
    public int getColumnCount() {
      return 1;
    }
  
    public Object getValueAt(int rowIndex, int columnIndex) {
      return new Integer(rowIndex*rowIndex);
    }
    
    public String getTextForRow(int rowIndex) {
      return Integer.toString(rowIndex);
    }
  }
}
