/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat Inc.  You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license
   agreement you entered into with NetCat Inc.

   Copyright (c) 2003 - 2004 by NetCat Inc., www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/

import java.awt.*;

import li.netcat.print.*;
import li.netcat.print.util.*;

public class MyPageDecorator implements PageDecorator {
  private static Image LOGO = ImageLoader.loadImage("./images/Logo.gif");
  private Print _headerPrint;

  //// constructors
  
  public MyPageDecorator() {
    TextPrint textPrint = new TextPrint("ReportCat and ChartCat");
    textPrint.setFont(new Font(null, Font.BOLD, 16));
    ImagePrint imagePrint = new ImagePrint(LOGO, 104, 18);
    GridPrintConstraints c = GridPrintConstraints.DEFAULT;
    GridPrint gp = new GridPrint();
    gp.add(textPrint, c.colSpan(1));
    gp.add(imagePrint, c.colWidthPreferred());
    gp.add(new LinePrint());
    _headerPrint = gp;
  }
  
  public Print createHeader(PageNumber number) {
    return _headerPrint;
  }
  
  public int getHeaderGap(PageNumber number) {
    return 20;
  }
  
  public Print createFooter(PageNumber number) {
    GridPrint gp = new GridPrint();
    GridPrintConstraints c = GridPrintConstraints.DEFAULT;
    gp.add(new LinePrint());
    gp.add(new TextPrint("Copyright (c) 2003 by NetCat Inc. All rights reserved."), c.colSpan(1));
    gp.add(new PageNumberPrint(number), c.hAlignRight().colWidthPreferred());
    return gp;
  }
  
  public int getFooterGap(PageNumber number) {
    return 10;
  }
  
  private static class ImageLoader {
    private final static Component component = new Component() {};
    private final static MediaTracker tracker = new MediaTracker(component);

    public static Image loadImage(String fileName) {
      Image image = Toolkit.getDefaultToolkit().createImage(fileName);
      loadImage(image);
      return image;
    }
    
    private static void loadImage(Image image) {
      synchronized(tracker) {
        tracker.addImage(image, 0);
        try {
          tracker.waitForID(0, 0);
        } 
        catch (InterruptedException e) {
          System.out.println("INTERRUPTED while loading Image");
        }
        tracker.removeImage(image, 0);
      }
    }
  }
  
  private static class LinePrint implements Print {
  
    //// interface Print
  
    public Dimension getPreferredSize(Graphics g) {
      return new Dimension(1, 1);
    }
  
    public PrintIterator getPrintIterator() {
      return new LinePrintIterator();
    }
  }
  
  
  private static class LinePrintIterator implements PrintIterator {
    private boolean _available = true;
    
    //// interface PrintIterator
    
    public boolean hasNext() {
      return _available;
    }
  
    public Painter getNext(Graphics g, int width, int height) {
      _available = false;
      return new LinePainter(width);
    }
  }

  private static class LinePainter extends FixSizePainter {
    
    //// constructor
    
    public LinePainter(int width) {
      super(width, 1);
    }
  
    //// implementation of abstract metods
    
    public void paint(Graphics g, int x, int y) {
      g.setColor(Color.black);
      g.fillRect(x, y, super.getWidth(), super.getHeight());
    }
  }
}
