/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat Inc.  You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license
   agreement you entered into with NetCat Inc.

   Copyright (c) 2004 by NetCat AG, www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/
import java.awt.*;

import li.netcat.chart.*;
import li.netcat.chart.data.*;
import li.netcat.chart.util.*;
import li.netcat.chart.util.tag.*;

public class PenBoxExample {
  
  public static void main(String[] args) {
    FrameHelper.open(new RadarLineChart(new MyChartModel()));
  }
  
  public static class RadarLineChart extends Chart {
          
    public RadarLineChart(ChartModel chartModel) {

      // prepare radar line part
      RadarLinePart radarLinePart = new RadarLinePart(chartModel);
      radarLinePart.setSize(140f, 8f);
      radarLinePart.setPaintSymbols(false);
      // set a static scale model that starts at 10, has marks at 40, 60 and ends at 90
      radarLinePart.setRadialScaleModel(new StaticScaleModel(new double[]{10, 40, 60, 90})); 
      // prepare a own graph look
      GraphLook look = new GraphLook();
      // define the pens that are used to paint the lines of the chart
      look.setLineChartPenBox(new MyLineChartPenBox());
      // set the look to the graph
      radarLinePart.setGraphLook(look);

      // prepare the grid
      PolarGridPart grid = new PolarGridPart(radarLinePart);
      // define different background colors
      grid.setBackgroundPenBox(new MyBackgroundPenBox());
      // define different pens for the ring lines
      grid.setRingPenBox(new MyRingPenBox());
      // define a pen box for the spokes and the polar scale
      PenBox scalePenBox = new MyScalePenBox();
      // paint the spokes with the scale pen box
      grid.setSpokePenBox(scalePenBox);
        
      // prepare a polar scale
      PolarScalePart polarScalePart = new PolarScalePart(radarLinePart);
      // paint the text with the scale pen box
      polarScalePart.setTextPenBox(scalePenBox);
      // paint the lineswith the scale pen box
      polarScalePart.setLinePenBox(scalePenBox);
        
      // add everyting to a panel
      PanelPart panel = new PanelPart();
      panel.addPart(grid);
      panel.addPart(radarLinePart);
      panel.addPart(polarScalePart);
      setContent(panel);
    }
  }
  
  public static class MyLineChartPenBox extends ListPenBox {
    
    //// constructor
    
    public MyLineChartPenBox() {
      Stroke stroke = new BasicStroke(3f, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND);
      setPens(new Pen[] {new Pen(stroke, Color.red),
                         new Pen(stroke, Color.blue),
              });
    }
  }

  
  public static class MyScalePenBox extends ListPenBox {
    
    //// constructor
    
    public MyScalePenBox() {
      Stroke stroke = new BasicStroke(0.5f);
      setPens(new Pen[] {
                       new Pen(stroke, new Color(247, 170, 158), new Color(222, 33, 4)),
                       new Pen(stroke, new Color(133, 194, 229), new Color(27, 92, 128)),
                       new Pen(stroke, new Color(165, 222, 162), new Color(42, 115, 38)),
                       new Pen(stroke, Color.lightGray, Color.black),
              });
    }
    
    //// overridden methods
    
    public Pen getPenAt(int index) {
      // do some index calculation "business logic"
      index /= 12;
      return super.getPenAt(index);
    }
  }

  
  public static class MyBackgroundPenBox implements PenBox {
    Pen pen0 = new Pen(new Color(254, 226, 210));
    Pen pen1 = new Pen(new Color(230, 230, 230));
    
    //// implementation of PenBox
    
    public Pen getPenAt(int index) {
      return index == 1 ? pen0 : pen1;
    }
  }

  
  public static class MyRingPenBox implements PenBox {
    Pen pen0 = new Pen(new BasicStroke(0.5f), Color.black);
    Pen pen1 = new Pen(new BasicStroke(8f), new Color(254, 226, 210));
    
    //// implementation of PenBox
    
    public Pen getPenAt(int index) {
      if (index == 1 || index == 2) {
        return pen0;
      }
      if (index == 3) {
        return pen1;
      }
      return null;
    }
  }
  

  
  public static class MyChartModel extends AbstractChartModel {
    private String[] _names = new String[] {"Elisabeth", "Christian", "Ingrid", "Angelo", "Georg", 
       "Erna", "Bernadette", "Franzisca", "Mirjam", "Gisela", "Markus", "Simon", "Olivier", "Sandra", 
       "Annemarie", "Norman", "Pascal", "Rene", "Juan", "Dave", "Katja", "Barbara", "Riccarda",
       "Yves", "Jakob", "Lein", "Dominic", "Angelika", "Markus", "Ramon", "Ursi", "Stefanie", "Bruno",
       "Peter", "Yvonne", "Petra", "Brigitte", "Simone", "Pascale"};
  
    //// overridden methods
    
    public int getRowCount() {
      return _names.length;
    }
  
    public int getColumnCount() {
      return 1;
    }
  
    public Object getValueAt(int rowIndex, int columnIndex) {
      // create some funny data
      return new Integer((rowIndex*76543 + columnIndex*101)%40 + 30);
    }
    
    public String getTextForRow(int rowIndex) {
      return _names[rowIndex];
    }
  }
}
