/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat Inc.  You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license
   agreement you entered into with NetCat Inc.

   Copyright (c) 2003 - 2004 by NetCat Inc., www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/
import java.awt.*;

import li.netcat.chart.*;
import li.netcat.chart.util.*;
import li.netcat.chart.util.tag.*;

public class PerspectiveExample {
  
  public static void main(String[] args) {
    GraphLook look = new GraphLook();
    //look.setBoundLinePen(null);
    GraphLook.setDefault(look);
    FrameHelper.open(createCharts(), -1, 3);
    FrameHelper.open(createCharts2(), -1, 2);
  }
  
  public static Chart[] createCharts() {
    ChartModel model = new StudentsChartModel();
    return new Chart[] {
        new BarChart(model, ChartConstants.STACK_TYPE_NOT_STACKED, ChartConstants.HORIZONTAL),
        new BarChart(model, ChartConstants.STACK_TYPE_STACKED, ChartConstants.HORIZONTAL),
        new BarChart(model, ChartConstants.STACK_TYPE_STACKED_PERCENT, ChartConstants.HORIZONTAL),
        new BarChart(model, ChartConstants.STACK_TYPE_NOT_STACKED, ChartConstants.VERTICAL),
        new BarChart(model, ChartConstants.STACK_TYPE_STACKED, ChartConstants.VERTICAL),
        new BarChart(model, ChartConstants.STACK_TYPE_STACKED_PERCENT, ChartConstants.VERTICAL),
        new AreaChart(model, ChartConstants.STACK_TYPE_NOT_STACKED, ChartConstants.HORIZONTAL),
        new AreaChart(model, ChartConstants.STACK_TYPE_STACKED, ChartConstants.HORIZONTAL),
        new AreaChart(model, ChartConstants.STACK_TYPE_STACKED_PERCENT, ChartConstants.HORIZONTAL),
        new AreaChart(model, ChartConstants.STACK_TYPE_NOT_STACKED, ChartConstants.VERTICAL),
        new PieChart(model),
        new RingChart(model),
        new LineChart(model, ChartConstants.STACK_TYPE_NOT_STACKED, ChartConstants.HORIZONTAL, true, false),  
        new LineChart(model, ChartConstants.STACK_TYPE_STACKED, ChartConstants.VERTICAL, true, true),
        new Legend(model), // normally, the legend is part of the chart itself.
    };
  }
  
  public static Chart[] createCharts2() {
    ChartModel model = new WeekdayChartModel();
    return new Chart[] {
        new RadarChart(model, ChartConstants.STACK_TYPE_STACKED),
        new RadarLineChart(model, ChartConstants.STACK_TYPE_NOT_STACKED),
    };
  }

  
  public static class BarChart extends CartesianChart {
    public BarChart(ChartModel model, int type, int orientation) {
      super(new BarPart(model, type, orientation));
    }
  }
  
  public static class AreaChart extends CartesianChart {
    public AreaChart(ChartModel model, int type, int orientation) {
      super(new AreaPart(model, type, orientation)); 
    }
  }
  
  public static class LineChart extends CartesianChart {
    public LineChart(ChartModel model, int type, int orientation, boolean paintLines, boolean paintSymbols) {
      super(new LinePart(model, type, orientation, paintLines, paintSymbols));
      getPerspectivePart().setLight(-10, 20); 
    }
  }
  
  public static class RadarChart extends PolarChart {
    public RadarChart(ChartModel model, int type) {
      super(new RadarPart(model, type));
    }
  }
  
  public static class RadarLineChart extends PolarChart {
    public RadarLineChart(ChartModel model, int type) {
      super(new RadarLinePart(model, type, true, false));
      getPerspectivePart().setLight(15, 30);
      PolarGridPart gridPart = getGridPart();
      Pen pen = gridPart.getSpokePen().fillPaint(Color.lightGray).outlinePaint(Color.black);
      gridPart.setSpokePen(pen);
      gridPart.setBorderPen(pen);
      gridPart.setInnerBorderPerspective(ChartConstants.PERSPECTIVE);
      gridPart.setOuterBorderPerspective(ChartConstants.BACKGROUND);
    }
  }

  public static class PieChart extends Chart {
    public PieChart(ChartModel model) {
      RingPart ringPart = new RingPart(new SumRowsChartModel(model), ChartConstants.STACK_TYPE_STACKED_PERCENT);
      ringPart.setSize(48, 0);
      ringPart.setRadialMove(0, 1, 10.0f);
      PanelPart panel = new PanelPart();
      panel.addPart(ringPart);
      panel.addPart(new PolarInscribePart(ringPart));
      setContent(new PerspectivePart(panel));
    }
  }
  
  public static class RingChart extends Chart {
    public RingChart(ChartModel model) {
      RingPart ringPart = new RingPart(model, ChartConstants.STACK_TYPE_STACKED_PERCENT);
      ringPart.setSize(35, 20);
      ringPart.setRadialMove(3, 1, 20.0f);
      ringPart.setRadialMove(3, 0, 20.0f);
      CartesianScalePart cartesianScalePart = new CartesianScalePart(ringPart, ChartConstants.LEFT);
      cartesianScalePart.setAdditionalLineLength(ringPart.getRadius()+5);
      cartesianScalePart.setTagManager(new DefaultTagManager(DefaultTagManager.STYLE_UNDERLINE, DefaultTagManager.METHOD_MOVE));
      cartesianScalePart.setPen(Pen.getDefaultCapButt());
      PanelPart panel = new PanelPart();
      panel.addPart(ringPart);
      panel.addPart(cartesianScalePart);
      setContent(new PerspectivePart(panel));
    }
  }
  
  public static class CartesianChart extends Chart {
    private PerspectivePart _perspectivePart;
    
    public CartesianChart(CartesianGraphPart cartesianGraphPart) {
      cartesianGraphPart.setSize(140, 100);
      CartesianGridPart cartesianGridPart = new CartesianGridPart(cartesianGraphPart);
      if (cartesianGraphPart.getOrientation() == CartesianGraphPart.VERTICAL) {
        cartesianGridPart.flipFlags();
      }
      PanelPart panel = new PanelPart();
      panel.addPart(cartesianGraphPart);
      panel.addPart(cartesianGridPart);
      panel.addPart(new CartesianScalePart(cartesianGraphPart, CartesianScalePart.LEFT));
      panel.addPart(new CartesianScalePart(cartesianGraphPart, CartesianScalePart.BOTTOM));
      _perspectivePart = new PerspectivePart(panel);
      setContent(_perspectivePart);
    }
    
    public PerspectivePart getPerspectivePart() {
      return _perspectivePart;
    }
  }
  
  public static class PolarChart extends Chart {
    private PerspectivePart _perspectivePart;
    private PolarGridPart   _gridPart;
    
    public PolarChart(PolarGraphPart polarGraphPart) {
      polarGraphPart.setSize(70, 20);
      PanelPart panel = new PanelPart();
      _gridPart = new PolarGridPart(polarGraphPart);
      //_gridPart.setSpokePen(Pen.getDefaultCapRound());
      panel.addPart(_gridPart);
      panel.addPart(polarGraphPart);
      panel.addPart(new PolarScalePart(polarGraphPart));
      _perspectivePart = new PerspectivePart(panel);
      setContent(_perspectivePart);
    }

    public PerspectivePart getPerspectivePart() {
      return _perspectivePart;
    }
    
    public PolarGridPart getGridPart() {
      return _gridPart;
    }
  }
  
  
  public static class Legend extends Chart {
    
    public Legend(ChartModel model) {
      BarPart dummy = new BarPart(model); // in normal cases, this graph part is also added to the chart.
      
      AreaLegendPart areaLegend = new AreaLegendPart(dummy);
      areaLegend.setPerspective(ChartConstants.PERSPECTIVE);
      areaLegend.setItemTextGap(10);
      PerspectivePart persAreaLegend = new PerspectivePart(areaLegend);
      persAreaLegend.setVanishingPoint(4, -4);
      
      LineLegendPart lineLegend = new LineLegendPart(dummy);
      lineLegend.setPerspective(ChartConstants.PERSPECTIVE);
      lineLegend.setItemTextGap(8);
      PerspectivePart persLineLegend = new PerspectivePart(lineLegend);
      persLineLegend.setVanishingPoint(4, -4);
      persLineLegend.setLight(-10, 20);
      
      PanelPart panel = new PanelPart();
      PanelPartConstraints c = PanelPartConstraints.DEFAULT;
      panel.addPart(persAreaLegend);
      panel.addPart(persLineLegend, c.anchorSouthWest().targetNorthWest().shiftY(1));
      setContent(new BorderPart(panel));
    }
  }
      
  
  public static class StudentsChartModel extends ExampleChartModel {
  
    //// constructors
    
    public StudentsChartModel() {
      super(new String[] {"Deutsch", "Englisch", "Chemie", "Physik"}, 
            new String[] {"Alexandra", "Debora", "Lukas"},
            new int[] {77, 90, 60, 75,
                       65, 55, 15, 20, 
                       35, 10, 85, 52,
            });
    }
  }

  public static class WeekdayChartModel extends ExampleChartModel {
  
    public WeekdayChartModel() {
      super(new String[] {"Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag", "Samstag", "Sonntag"}, 
            new String[] {"George", "Silvan", "Larissa"},
            new int[] {
              15, 13, 4, 12, 5, 18, 14,
              6, 17, 10, 2, 9, 3, 19,
              8, 10, 7, 15, 14, 9, 12,
            });
    }

  }
}
