/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat Inc.  You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license
   agreement you entered into with NetCat Inc.

   Copyright (c) 2003 - 2004 by NetCat Inc., www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/
import java.awt.*;

import li.netcat.chart.*;
import li.netcat.chart.data.*;
import li.netcat.chart.util.*;
import li.netcat.chart.util.tag.*;

import li.netcat.print.*;
import li.netcat.print.table.*;
import li.netcat.print.util.*;

public class PrintExample {
  
  public static void main(String[] args)	{
    new PrintPreview(new PagePrint(createPrint(), new MyPageDecorator())).open();
  }
  
  public static Print createPrint() {
    ChartModel chartModel = new TemperatureChartModel();
    TableDataModel tableModel = new ChartModelTableDataModelAdapter(chartModel);
    TablePrint table = new TablePrint(tableModel);
    table.setFitWidth(true);
    table.setCellDrawer(Number.class, table.createDefaultCellDrawer(PrintConstants.RIGHT));
    ChartPrint chart = new ChartPrint(new LineChart(chartModel));
    GridPrint gridPrint = new GridPrint(20, 20);
    GridPrintConstraints c = GridPrintConstraints.DEFAULT.hAlignCenter();
    gridPrint.add(chart, c);
    gridPrint.add(table, c);
    return gridPrint;
  }

  public static class LineChart extends Chart {
    
    public LineChart(ChartModel chartModel) {
      LinePart linePart = new LinePart(chartModel);
      linePart.setSize(260, 160);
      ((DefaultStackModel)linePart.getStackModel()).setIncludeZero(false);
      CartesianGridPart grid = new CartesianGridPart(linePart);
      CartesianScalePart scaleX = new CartesianScalePart(linePart, ChartConstants.BOTTOM);
      CartesianScalePart scaleY = new CartesianScalePart(linePart, ChartConstants.LEFT);
      LineLegendPart legend = new LineLegendPart(linePart);
      LabelPart title = new LabelPart("Temperaturverlauf");
      title.setTextLook(TextLook.getDefaultLarge());
      PanelPart panel = new PanelPart();
      PanelPartConstraints c = PanelPartConstraints.DEFAULT;
      panel.addPart(grid);
      panel.addPart(linePart);
      panel.addPart(scaleX);
      panel.addPart(scaleY);
      BorderPart border = new BorderPart(legend);
      border.setBackgroundPaint(Color.white);
      panel.addPart(border, c.reference(grid).anchorNorthEast().targetNorthEast());
      panel.addPart(title, c.referenceX(grid).anchorNorth().targetSouth().shiftY(-12));
      PerspectivePart perspectivePart = new PerspectivePart(panel);
      perspectivePart.setLight(5, 10);
      setContent(perspectivePart);
    }
  }
  
  public static class TemperatureChartModel extends ExampleChartModel {
  
    //// constructors
    
    public TemperatureChartModel() {
      super(
            new String[] {"Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag", "Samstag", "Sonntag"}, 
            new String[] {"Luft", "Boden", "Wasser"},
            new double[] {
            22.1, 23.4, 23.5, 21.1, 18.3, 19.0, 19.5,
            20.3, 19.6, 20.7, 20.8, 19.9, 17.3, 16.5,
            16.4, 16.8, 17.1, 17.2, 16.9, 17.0, 17.5,
            });
    }
  }
  
  public static class ChartModelTableDataModelAdapter implements TableDataModel {
    private ChartModel _chartModel;
    
    //// constructors
    
    public ChartModelTableDataModelAdapter(ChartModel chartModel) {
      _chartModel = chartModel;
    }
    
    public int getRowCount() {
      return _chartModel.getRowCount();
    }
    
    public int getColumnCount() {
      return _chartModel.getColumnCount() + 1;
    }
    
    public Object getValueAt(int rowIndex, int columnIndex) {
      if (columnIndex == 0) {
        return _chartModel.getTextForRow(rowIndex);
      }
      return _chartModel.getTextAt(rowIndex, columnIndex-1);
    }
    
    public Object getValueTypeAt(int rowIndex, int columnIndex) {
      if (columnIndex == 0) {
        return String.class;
      }
      return Number.class;
    }
    
    public boolean hasHeader() {
      return true;
    }

    public Object getHeaderAt(int columnIndex) {
      if (columnIndex == 0) {
        return "Tag";
      }
      return _chartModel.getTextForColumn(columnIndex-1);
    }
    
    public Object getHeaderTypeAt(int columnIndex) {
      return String.class;
    }
    
    public boolean hasFooter() {
      return false;
    }
    
    public Object getFooterAt(int columnIndex) {
      return null;
    }
    
    public Object getFooterTypeAt(int columnIndex) {
      return null;
    }
    
  }
  
}
