/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat Inc.  You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license
   agreement you entered into with NetCat Inc.

   Copyright (c) 2003 - 2004 by NetCat Inc., www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/

import java.awt.*;
import java.awt.event.*;
import java.awt.print.*;

import javax.swing.*;
import javax.swing.border.*;

import li.netcat.print.*;

public class PrintPreview extends JPanel implements ActionListener {
  private PreviewPanel _previewPanel;
  private JButton      _nextPageButton;
  private JButton      _previousPageButton;
  private JButton      _zoomOutButton;
  private JButton      _zoomInButton;
  private JButton      _scaleOutButton;
  private JButton      _scaleInButton;
  private JButton      _orientationButton;
  private JButton      _resetButton;
  private JButton      _pageDialogButton;
  private JButton      _printButton;
  
  //// constructors

  public PrintPreview(Print print) {
    super(new BorderLayout(5, 5));
    setBorder(new EmptyBorder(5, 5, 5, 5));
    _previewPanel = new PreviewPanel(print);
    add(new JScrollPane(_previewPanel), BorderLayout.CENTER);
    JPanel buttonPanel = new JPanel(new BorderLayout(0, 5));
    add(buttonPanel, BorderLayout.EAST);
    JPanel topComponents = new JPanel(new GridLayout(-1, 1, 0, 3));
    buttonPanel.add(topComponents, BorderLayout.NORTH);
    JPanel tmpPanel = new JPanel(new GridLayout(1, -1, 3, 3));
    tmpPanel.add(_previousPageButton = createButton("<"));
    tmpPanel.add(_nextPageButton = createButton(">"));
    topComponents.add(tmpPanel);
    tmpPanel = new JPanel(new GridLayout(1, -1, 3, 3));
    tmpPanel.add(_zoomOutButton = createButton("Zoom -"));
    tmpPanel.add(_zoomInButton = createButton("Zoom +"));
    topComponents.add(tmpPanel);
    topComponents.add(_orientationButton = createButton("Orientation"));
    topComponents.add(_pageDialogButton = createButton("Pagedialog"));
    tmpPanel = new JPanel(new GridLayout(1, -1, 3, 3));
    tmpPanel.add(_scaleOutButton = createButton("Scale -"));
    tmpPanel.add(_scaleInButton = createButton("Scale +"));
    topComponents.add(tmpPanel);
    topComponents.add(_resetButton = createButton("Reset"));
    topComponents.add(_printButton = createButton("Print"));
  }
  
  public void actionPerformed(ActionEvent event) {
    Object source = event.getSource();
    if (source == _nextPageButton) {
      _previewPanel.nextPage();
    }
    else if (source == _previousPageButton) {
      _previewPanel.previousPage();
    }
    else if (source == _zoomOutButton) {
      _previewPanel.setZoom(_previewPanel.getZoom() / 1.3);
    }
    else if (source == _zoomInButton) {
      _previewPanel.setZoom(_previewPanel.getZoom() * 1.3);
    }
    else if (source == _scaleOutButton) {
      _previewPanel.getPrintManager().setScaleValue(_previewPanel.getPrintManager().getScaleValue() / 1.1);
    }
    else if (source == _scaleInButton) {
      _previewPanel.getPrintManager().setScaleValue(_previewPanel.getPrintManager().getScaleValue() * 1.1);
    }
    else if (source == _orientationButton) {
      int newOrientation = _previewPanel.getPrintManager().getOrientation() == PrintConstants.PORTRAIT ? PrintConstants.LANDSCAPE : PrintConstants.PORTRAIT;
      _previewPanel.getPrintManager().setOrientation(newOrientation);
    }
    else if (source == _resetButton) {
      PrintManager pm = _previewPanel.getPrintManager();
      pm.setPageFormat(pm.getPrinterJob().defaultPage());
      pm.setScaleValue(1.0);
      _previewPanel.setZoom(1.0);
    }
    else if (source == _pageDialogButton) {
      _previewPanel.getPrintManager().pageDialog(true);
    }
    else if (source == _printButton) {
      try {
        _previewPanel.getPrintManager().print(true);
      }
      catch (PrinterException x) {
        x.printStackTrace();
      }
    }
  }

  //// public methods
  
  public JFrame open() {
    JFrame frame = new JFrame();
    frame.setContentPane(this);
    frame.pack();
    frame.setVisible(true);
    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    frame.toFront();
    return frame;
  }
  
  public PreviewPanel getPreviewPanel() {
    return _previewPanel;
  }
  
  //// commands
 
  private JButton createButton(String text) {
    JButton button = new JButton(text);
    button.addActionListener(this);
    return button;
  }
 
 
}