/*******************************************************************

   This software is the confidential  and proprietary information of
   NetCat Inc.  You shall not disclose such confidential information
   and shall use it only in accordance with the terms of the license
   agreement you entered into with NetCat Inc.

   Copyright (c) 2003 - 2004 by NetCat Inc., www.netcat.li

   Author: Arthur Marxer, Dipl. Informatik-Ing. ETH

*******************************************************************/

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import li.netcat.chart.*;
import li.netcat.chart.util.*;


public class TooltipExample {
  
  public static void main(String[] args)	{
    ChartModel model = new SimpleChartModel(4, 3, "Bar Chart Example", "x Axis", "y Axis");
    ChartPanel chartPanel = new ChartPanel(new BarChart(model));
    new MyTooltipHandler(chartPanel).install();
    FrameHelper.open(new JScrollPane(chartPanel));
    ToolTipManager.sharedInstance().setInitialDelay(0);
  }
  
  public static class BarChart extends Chart {
    
    public BarChart(ChartModel chartModel) {
      BarPart barPart = new BarPart(chartModel);
      CartesianGridPart grid = new CartesianGridPart(barPart);
      CartesianScalePart scaleX = new CartesianScalePart(barPart, ChartConstants.BOTTOM);
      CartesianScalePart scaleY = new CartesianScalePart(barPart, ChartConstants.LEFT);
      AreaLegendPart legend = new AreaLegendPart(barPart);
      legend.setSquareSize(70f);
      LabelPart title = new LabelPart(chartModel, "title");
      title.setTextLook(TextLook.getDefaultLarge());
      LabelPart xAxis =  new LabelPart(chartModel, "x");
      xAxis.setTextLook(TextLook.getDefaultMedium());
      LabelPart yAxis =  new LabelPart(chartModel, "y");
      yAxis.setTextLook(TextLook.getDefaultMedium());
      yAxis.setAngleDegrees(90);
      PanelPart panel = new PanelPart();
      PanelPartConstraints c = PanelPartConstraints.DEFAULT;
      panel.addPart(grid);
      panel.addPart(barPart);
      panel.addPart(scaleX);
      panel.addPart(scaleY);
     // BorderPart borderPart = new BorderPart(legend);
      
      panel.addPart(legend, c.reference(grid).anchorEast().targetWest().shiftX(10));
      panel.addPart(xAxis, c.referenceX(grid).anchorSouth().targetNorth().shiftY(5));
      panel.addPart(yAxis, c.referenceY(grid).anchorWest().targetEast().shiftX(-5));
      panel.addPart(title, c.anchorNorth().targetSouth().shiftY(-10));
      //setContent(new PerspectivePart(panel));
      setContent(panel);
    }
  }
  
  // private helper class for tooltips

  private static class MyTooltipHandler extends MouseMotionAdapter {
    private ChartPanel _chartPanel;
    
    //// constructor
    
    public MyTooltipHandler(ChartPanel chartPanel) {
      _chartPanel = chartPanel;
    }
    
    //// public methods
    
    public void install() {
      ToolTipManager.sharedInstance().registerComponent(_chartPanel);
      _chartPanel.addMouseMotionListener(this);
    }
    
    public void uninstall() {
      ToolTipManager.sharedInstance().unregisterComponent(_chartPanel);
      _chartPanel.removeMouseMotionListener(this);
    }
    
    //// overridden methods
    
    public void mouseMoved(MouseEvent e) {
      Point p = e.getPoint();
      int x = p.x;
      int y = p.y;
      LogicalPoint lp = _chartPanel.getLogicalPoint(p);
      if (p.x != x || p.y != y) {
        throw new RuntimeException("point moved");
      }
      String text = null;
      if (lp != null) {
        ChartModel model = lp.getChartModel();
        if (model != null) {
          // use lp and model to calculate the tooltip text
          int col = lp.getColumnIndex();
          int row = lp.getRowIndex();
          if (row >= 0) {
            if (col >= 0) {
              text = model.getTextAt(row, col);
            }
            else {
              text = model.getTextForRow(row);
            }
          }
          else {
            if (col >= 0) {
              text = model.getTextForColumn(col);
            }
          }
        }
      }
      _chartPanel.setToolTipText(text);
    }
  }
  

}
